pub enum Color {
White0,
White1,
Gray,
Black,
}Expand description
A traced color in the tri-color invariant.
Variants
White0
Not yet visited in the current cycle. The collector alternates between two white bits so allocations made during sweep are not collected by the cycle already in progress.
White1
Alternate white bit.
Gray
Visited; outgoing references not yet traced.
Black
Fully traced; no outgoing pointers to white objects.
Implementations