pub enum StepOutcome {
Paused,
InProgress,
SkippedStopped,
}Expand description
Outcome of one call to Heap::incremental_step_with_post_mark.
Variants
Paused
The step finished a cycle. The heap is back at GcState::Pause.
InProgress
The step performed work but the cycle is not finished. Caller may step again.
SkippedStopped
The heap is paused (via [Heap::pause]) or the caller asked for zero
budget while no cycle was in progress and no work was needed.