pub struct AllGcCohortStats {
pub new: usize,
pub survival: usize,
pub old1: usize,
pub old: usize,
}Expand description
Diagnostic counts for the allgc list split by generational cursors.
Fields
new: usizesurvival: usizeold1: usizeold: usizeTrait Implementations
Sourceimpl Clone for AllGcCohortStats
impl Clone for AllGcCohortStats
Sourcefn clone(&self) -> AllGcCohortStats
fn clone(&self) -> AllGcCohortStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AllGcCohortStats
impl Debug for AllGcCohortStats
Sourceimpl Default for AllGcCohortStats
impl Default for AllGcCohortStats
Sourcefn default() -> AllGcCohortStats
fn default() -> AllGcCohortStats
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AllGcCohortStats
impl PartialEq for AllGcCohortStats
Sourcefn eq(&self, other: &AllGcCohortStats) -> bool
fn eq(&self, other: &AllGcCohortStats) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for AllGcCohortStats
impl Eq for AllGcCohortStats
impl StructuralPartialEq for AllGcCohortStats